@@ -17,9 +17,10 @@ from .config import load_config
 
 try:
     if os.environ.get("PUREPYTHONHUNTER"):
-        raise ImportError("Skipped")
+        raise ImportError("Cython speedups are disabled")
 
     from ._predicates import And as _And
+    from ._predicates import From
     from ._predicates import Not
     from ._predicates import Or as _Or
     from ._predicates import When
@@ -27,18 +28,20 @@ try:
     from ._tracer import Tracer
 except ImportError:
     from .predicates import And as _And
+    from .predicates import From
     from .predicates import Not
     from .predicates import Or as _Or
     from .predicates import When
     from .predicates import Query
     from .tracer import Tracer
 
-__version__ = "__version__ = '2.1.0'"
+__version__ = '2.2.1'
 __all__ = (
     'And',
     'CallPrinter',
     'CodePrinter',
     'Debugger',
+    'From',
     'Manhole',
     'Not',
     'Or',
@@ -228,11 +231,16 @@ def wrap(function_to_trace=None, **trace_options):
     def tracing_decorator(func):
         @functools.wraps(func)
         def tracing_wrapper(*args, **kwargs):
-            tracer = trace(~When(Q(calls_gt=0, depth=0), Stop), **trace_options)
+            predicates = []
+            local = trace_options.pop('local', False)
+            if local:
+                predicates.append(Q(depth_lt=2))
+            predicates.append(~When(Q(calls_gt=0, depth=0) & ~Q(kind='return'), Stop))
+            local_tracer = trace(*predicates, **trace_options)
             try:
                 return func(*args, **kwargs)
             finally:
-                tracer.stop()
+                local_tracer.stop()
         return tracing_wrapper
     if function_to_trace is None:
         return tracing_decorator
